Sommaire

zabbix_sender

ZABBIX_SENDER(1)            Manuel des commandes générales           ZABBIX_SENDER(1)

NOM
       zabbix_sender - utilitaire d'envoi de données Zabbix

SYNOPSIS
       zabbix_sender [-v] -z serveur [-p port] [-I adresse-IP] [-t délai] -s
       hôte -k clé -o valeur
       zabbix_sender [-v] -z serveur [-p port] [-I adresse-IP] [-t délai] [-s
       hôte] [-T] [-N] [-r] -i fichier-d'entrée
       zabbix_sender [-v] -c fichier-de-configuration [-z serveur] [-p port] [-I adresse-IP]
       [-t délai] [-s hôte] -k clé -o valeur
       zabbix_sender [-v] -c fichier-de-configuration [-z serveur] [-p port] [-I adresse-IP]
       [-t délai] [-s hôte] [-T] [-N] [-r] -i fichier-d'entrée
       zabbix_sender [-v] -z serveur [-p port] [-I adresse-IP] [-t délai] -s
       hôte --tls-connect cert --tls-ca-file fichier-CA [--tls-crl-file fichier-CRL]
       [--tls-server-cert-issuer émetteur-du-certificat] [--tls-server-cert-subject
       sujet-du-certificat] --tls-cert-file fichier-du-certificat --tls-key-file fichier-de-clé
       [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher chaîne-de-chiffrement] -k clé -o
       valeur
       zabbix_sender [-v] -z serveur [-p port] [-I adresse-IP] [-t délai] [-s
       hôte] --tls-connect cert --tls-ca-file fichier-CA [--tls-crl-file
       fichier-CRL] [--tls-server-cert-issuer émetteur-du-certificat]
       [--tls-server-cert-subject sujet-du-certificat] --tls-cert-file fichier-du-certificat
       --tls-key-file fichier-de-clé [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher
       chaîne-de-chiffrement] [-T] [-N] [-r] -i fichier-d'entrée
       zabbix_sender [-v] -c fichier-de-configuration [-z serveur] [-p port] [-I adresse-IP]
       [-t délai] [-s hôte] --tls-connect cert --tls-ca-file fichier-CA
       [--tls-crl-file fichier-CRL] [--tls-server-cert-issuer émetteur-du-certificat]
       [--tls-server-cert-subject sujet-du-certificat] --tls-cert-file fichier-du-certificat
       --tls-key-file fichier-de-clé [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher
       chaîne-de-chiffrement] -k clé -o valeur
       zabbix_sender [-v] -c fichier-de-configuration [-z serveur] [-p port] [-I adresse-IP]
       [-t délai] [-s hôte] --tls-connect cert --tls-ca-file fichier-CA
       [--tls-crl-file fichier-CRL] [--tls-server-cert-issuer émetteur-du-certificat]
       [--tls-server-cert-subject sujet-du-certificat] --tls-cert-file fichier-du-certificat
       --tls-key-file fichier-de-clé [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher
       chaîne-de-chiffrement] [-T] [-N] [-r] -i fichier-d'entrée
       zabbix_sender [-v] -z serveur [-p port] [-I adresse-IP] [-t délai] -s
       hôte --tls-connect psk --tls-psk-identity identité-PSK --tls-psk-file
       fichier-PSK [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher chaîne-de-chiffrement] -k
       clé -o valeur
       zabbix_sender [-v] -z serveur [-p port] [-I adresse-IP] [-t délai] [-s
       hôte] --tls-connect psk --tls-psk-identity identité-PSK --tls-psk-file
       fichier-PSK [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher chaîne-de-chiffrement]
       [-T] [-N] [-r] -i fichier-d'entrée
       zabbix_sender [-v] -c fichier-de-configuration [-z serveur] [-p port] [-I adresse-IP]
       [-t délai] [-s hôte] --tls-connect psk --tls-psk-identity identité-PSK
       --tls-psk-file fichier-PSK [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher
       chaîne-de-chiffrement] -k clé -o valeur
       zabbix_sender [-v] -c fichier-de-configuration [-z serveur] [-p port] [-I adresse-IP]
       [-t délai] [-s hôte] --tls-connect psk --tls-psk-identity identité-PSK
       --tls-psk-file fichier-PSK [--tls-cipher13 chaîne-de-chiffrement] [--tls-cipher
       chaîne-de-chiffrement] [-T] [-N] [-r] -i fichier-d'entrée
       zabbix_sender -h
       zabbix_sender -V

DESCRIPTION
       zabbix_sender est un utilitaire en ligne de commande permettant d'envoyer des données de
       supervision au serveur Zabbix ou au proxy. Sur le serveur Zabbix, un élément de type
       Zabbix trapper doit être créé avec la clé correspondante. Notez que les valeurs entrantes
       ne seront acceptées que depuis les hôtes indiqués dans le champ Hôtes autorisés de cet
       élément.

OPTIONS
       -c, --config fichier-de-configuration
              Utiliser fichier-de-configuration. Zabbix sender lit les détails du serveur dans
              le fichier de configuration de agentd. Par défaut, Zabbix sender ne lit aucun
              fichier de configuration. Seuls les paramètres Hostname, ServerActive,
              SourceIP, TLSConnect, TLSCAFile, TLSCRLFile, TLSServerCertIssuer,
              TLSServerCertSubject, TLSCertFile, TLSKeyFile, TLSPSKIdentity et TLSPSKFile sont
              pris en charge. Le Hostname défini via le paramètre HostnameItem ne sera pas
              récupéré ; dans ce cas, le nom d'hôte doit être indiqué via la ligne de commande
              (voir l'option -s). Toutes les adresses définies dans le paramètre de configuration
              ServerActive de l'agent sont utilisées pour l'envoi des données. Si l'envoi d'un
              lot de données échoue vers une adresse, les lots suivants ne sont pas envoyés à
              cette adresse.

       -z, --zabbix-server serveur
              Nom d'hôte ou adresse IP du serveur Zabbix. Si un hôte est supervisé par un proxy,
              le nom d'hôte ou l'adresse IP du proxy doit être utilisé à la place. Utilisé avec
              --config, ce paramètre remplace les entrées du paramètre ServerActive indiquées
              dans le fichier de configuration de agentd.

       -p, --port port
              Indiquer le numéro de port du trapper du serveur Zabbix exécuté sur le serveur. La
              valeur par défaut est 10051. Utilisé avec --config, ce paramètre remplace les
              entrées de port du paramètre ServerActive indiquées dans le fichier de configuration
              de agentd.

       -I, --source-address adresse-IP
              Indiquer l'adresse IP source. Utilisé avec --config, ce paramètre remplace le
              paramètre SourceIP indiqué dans le fichier de configuration de agentd.

       -t, --timeout secondes
              Indiquer le délai d'attente. Plage valide : 1 à 300 secondes (valeur par défaut :
              60).

       -s, --host hôte
              Indiquer le nom de l'hôte auquel appartient l'élément (tel qu'il est enregistré
              dans l'interface Zabbix). L'adresse IP et le nom DNS de l'hôte ne fonctionneront
              pas. Utilisé avec --config, ce paramètre remplace le paramètre Hostname indiqué
              dans le fichier de configuration de agentd.

       -k, --key clé
              Indiquer la clé de l'élément auquel envoyer la valeur.

       -o, --value valeur
              Indiquer la valeur de l'élément.

       -i, --input-file fichier-d'entrée
              Charger les valeurs depuis un fichier d'entrée. Indiquer - comme <fichier-d'entrée>
              pour lire les valeurs depuis l'entrée standard. Chaque ligne du fichier contient,
              séparés par des espaces, les éléments suivants : <nom-hôte> <clé> <valeur>. Chaque
              valeur doit être indiquée sur sa propre ligne. Chaque ligne doit contenir
              3 entrées séparées par des espaces : <nom-hôte> <clé> <valeur>, où « nom-hôte » est
              le nom de l'hôte supervisé tel qu'il est enregistré dans l'interface Zabbix, « clé »
              est la clé de l'élément cible et « valeur » est la valeur à envoyer. Indiquer - comme
              <nom-hôte> pour utiliser le nom d'hôte du fichier de configuration de agent ou de
              l'argument --host.

              Exemple de ligne d'un fichier d'entrée :

               "Linux DB3" db.connections 43

              Le type de valeur doit être correctement défini dans la configuration de l'élément
              de l'interface Zabbix. Zabbix sender envoie jusqu'à 250 valeurs par connexion. Le
              contenu du fichier d'entrée doit être encodé en UTF-8. Toutes les valeurs du fichier
              d'entrée sont envoyées dans l'ordre séquentiel, de haut en bas. Les entrées doivent
              être formatées selon les règles suivantes :

                     • Les entrées entre guillemets et sans guillemets sont prises en charge.

                     • Le guillemet double est le caractère de délimitation.

                     • Les entrées contenant des espaces doivent être placées entre guillemets.

                     • Les caractères guillemet double et barre oblique inverse à l'intérieur d'une
                       entrée entre guillemets doivent être échappés avec une barre oblique inverse.

                     • L'échappement n'est pas pris en charge dans les entrées sans guillemets.

                     • Les séquences d'échappement de saut de ligne (\n) sont prises en charge dans
                       les chaînes entre guillemets.

                     • Les séquences d'échappement de saut de ligne sont supprimées à la fin d'une
                       entrée.

       -T, --with-timestamps
              Cette option ne peut être utilisée qu'avec l'option --input-file.

              Chaque ligne du fichier d'entrée doit contenir 4 entrées séparées par des espaces :
              <nom-hôte> <clé> <horodatage> <valeur>. L'horodatage doit être indiqué au format
              d'horodatage Unix. Si l'élément cible possède des déclencheurs qui le référencent,
              tous les horodatages doivent être dans un ordre croissant ; sinon, le calcul de
              l'événement ne sera pas correct.

              Exemple de ligne d'un fichier d'entrée :

               "Linux DB3" db.connections 1429533600 43

              Pour plus de détails, consultez l'option --input-file.

              Si une valeur horodatée est envoyée pour un hôte qui se trouve dans une période de
              maintenance de type « aucune donnée », cette valeur sera ignorée ; toutefois, il est
              possible d'envoyer une valeur horodatée pendant une période de maintenance expirée,
              et elle sera acceptée.

       -N, --with-ns
              Cette option ne peut être utilisée qu'avec l'option --with-timestamps.

              Chaque ligne du fichier d'entrée doit contenir 5 entrées séparées par des espaces :
              <nom-hôte> <clé> <horodatage> <ns> <valeur>.

              Exemple de ligne d'un fichier d'entrée :

               "Linux DB3" db.connections 1429533600 7402561 43

              Pour plus de détails, consultez l'option --input-file.

       -r, --real-time
              Envoyer les valeurs une par une dès leur réception. Cette option peut être utilisée
              lors de la lecture depuis l'entrée standard.

       --tls-connect valeur
              Méthode de connexion au serveur ou au proxy. Valeurs :

                   unencrypted
                               se connecter sans chiffrement (valeur par défaut)

                   psk         se connecter avec TLS et une clé prépartagée

                   cert        se connecter avec TLS et un certificat

       --tls-ca-file fichier-CA
              Chemin complet d'un fichier contenant les certificats des autorités de certification
              de niveau supérieur pour la vérification du certificat du pair.

       --tls-crl-file fichier-CRL
              Chemin complet d'un fichier contenant les certificats révoqués.

       --tls-server-cert-issuer émetteur-du-certificat
              Émetteur de certificat du serveur autorisé.

       --tls-server-cert-subject sujet-du-certificat
              Sujet de certificat du serveur autorisé.

       --tls-cert-file fichier-du-certificat
              Chemin complet d'un fichier contenant le certificat ou la chaîne de certificats.

       --tls-key-file fichier-de-clé
              Chemin complet d'un fichier contenant la clé privée.

       --tls-psk-identity identité-PSK
              Chaîne d'identité PSK.

       --tls-psk-file fichier-PSK
              Chemin complet d'un fichier contenant la clé prépartagée.

       --tls-cipher13 chaîne-de-chiffrement
              Chaîne de chiffrement pour OpenSSL 1.1.1 ou version ultérieure avec TLS 1.3.
              Remplace les critères de sélection de la suite de chiffrement par défaut. Cette
              option n'est pas disponible si la version d'OpenSSL est antérieure à 1.1.1.

       --tls-cipher chaîne-de-chiffrement
              Chaîne de priorité GnuTLS (pour TLS 1.2 et versions ultérieures) ou chaîne de
              chiffrement OpenSSL (uniquement pour TLS 1.2). Remplace les critères de sélection
              de la suite de chiffrement par défaut.

       -v, --verbose
              Mode détaillé ; -vv fournit davantage de détails.

       -h, --help
              Afficher cette aide et quitter.

       -V, --version
              Afficher les informations de version et quitter.

CODE DE SORTIE
       Le code de sortie est 0 si les valeurs ont été envoyées et ont toutes été traitées avec
       succès par le serveur. Si les données ont été envoyées, mais que le traitement d'au moins
       une valeur a échoué, le code de sortie est 2. Si l'envoi des données a échoué, le code de
       sortie est 1.

EXEMPLES
       zabbix_sender -c  /etc/zabbix/zabbix_agentd.conf  -k  mysql.queries  -o
       342.45
              Envoyer 342.45 comme valeur de l'élément mysql.queries de l'hôte supervisé. Utiliser
              l'hôte supervisé et le serveur Zabbix définis dans le fichier de configuration de
              l'agent.

       zabbix_sender -c /etc/zabbix/zabbix_agentd.conf -s "Monitored Host"  -k
       mysql.queries -o 342.45
              Envoyer 342.45 comme valeur de l'élément mysql.queries de l'hôte Monitored Host en
              utilisant le serveur Zabbix défini dans le fichier de configuration de l'agent.

       zabbix_sender -z 192.168.1.113 -i data_values.txt
              Envoyer les valeurs du fichier data_values.txt au serveur Zabbix dont l'adresse IP
              est 192.168.1.113. Les noms d'hôtes et les clés sont définis dans le fichier.

       echo "- hw.serial.number  1287872261  SQ4321ASDF"  |  zabbix_sender  -c
       /usr/local/etc/zabbix_agentd.conf -T -i -
              Envoyer une valeur horodatée depuis la ligne de commande au serveur Zabbix indiqué
              dans le fichier de configuration de l'agent. Le tiret dans les données d'entrée
              indique que le nom d'hôte doit également être utilisé depuis ce même fichier de
              configuration.

       echo '"Zabbix server" trapper.item ""' | zabbix_sender -z 192.168.1.113
       -p 10000 -i -
              Envoyer une valeur vide d'un élément au serveur Zabbix dont l'adresse IP est
              192.168.1.113, sur le port 10000, depuis la ligne de commande. Les valeurs vides
              doivent être indiquées par des guillemets doubles vides.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  cert  --tls-ca-file  /home/zabbix/zabbix_ca_file
       --tls-cert-file      /home/zabbix/zabbix_agentd.crt      --tls-key-file
       /home/zabbix/zabbix_agentd.key
              Envoyer 342.45 comme valeur de l'élément mysql.queries de l'hôte Monitored Host au
              serveur dont l'adresse IP est 192.168.1.113, en utilisant TLS avec un certificat.

       zabbix_sender -z 192.168.1.113  -s "Monitored Host" -k mysql.queries -o
       342.45  --tls-connect  psk  --tls-psk-identity  "PSK  ID Zabbix agentd"
       --tls-psk-file /home/zabbix/zabbix_agentd.psk
              Envoyer 342.45 comme valeur de l'élément mysql.queries de l'hôte Monitored Host au
              serveur dont l'adresse IP est 192.168.1.113, en utilisant TLS avec une clé
              prépartagée (PSK).

VOIR AUSSI
       Documentation

       zabbix_agentd(8),  zabbix_get(1),  zabbix_proxy(8),   zabbix_server(8),
       zabbix_js(1), zabbix_agent2(8), zabbix_web_service(8)

Zabbix                            2022-01-06                  ZABBIX_SENDER(1)